# Notes about Euler equations

Derivation of the Euler equations can be found in @rezzolla2013:
$$
  \partial_t \rho + \partial_x (\rho v) = 0,
$$
$$
  \partial_t v + v \partial_x v + \frac{1}{\rho} \partial_x p = 0,
$$
$$
  \rho \partial_t \epsilon + \rho v \partial_x \epsilon + p \partial_x v = 0,
$$
where the first equation expresses conservation of mass, 
the second equation is the actual Euler equation
(and all three equations are usually called hydrodynamics equations) and expresses
conservation of linear momentum and the first one describes conservation 
of internal energy. The variables appearing here are the energy density $\rho$,
the velocity $v$, the internal energy density $\epsilon$ and the pressure $p$.
By introducing the (Newtonian) total energy density 
$$
  e = \rho \epsilon + \frac{1}{2} \rho v^2
$$
one can rewrite the last equation in the form
$$
  \partial_t (\frac{1}{2} \rho v^2 + \rho \epsilon) 
  + \partial_x ((\frac{1}{2} \rho v^2 + \rho \epsilon + p) v) = 0.
$$
As one can see the hydrodynamics equations are a set of three PDEs, but four
independent variables appear. Because of this, it is required to specify 
an additional equation that relates the quantities $\rho, v, e, p$, e.g.
an equation of state
$$
  p = p(\rho, v, e).
$$

## Hydrodynamics equations @guermond2008

They have written the hydrodynamics equations in conservation form, that is,
$$
  \partial_{t} \vec{u} + \partial_{x} \vec{f}(\vec{u}) = 0,
$$
$$
  \vec{u} = 
  \begin{bmatrix}
    \rho \\ q \\ E
  \end{bmatrix},
  \qquad
  \vec{f}(\vec{u}) = 
  \begin{bmatrix}
    q \\ qv + p \\ v(E + p)
  \end{bmatrix}.
$$

They also introduced the linear momentum $q = \rho v$ and the total energy
per unit volume
$$
  E = \rho e + \frac{1}{2} \rho v^2.
$$
In this work they use an ideal gas equation of state
$$
  p = (\gamma - 1) \rho e,
$$
where $\gamma = 7/5$ is the ideal gas constant.

## Test problems

### Smooth problem

The following problem was taken over from @qiu2005, @guo2009 and adapted to
my needs:
The initial data
$$
  \rho(0,x) = 1 + \frac{1}{5} sin(2\pi x),
$$
$$
  q(0,x) = \rho(0,x)
$$
$$
  E(0,x) = \frac{1}{2} q(0,x),
$$
is given on the periodic interval $x \in [0,1)$.
The corresponding analytic solution to this problem is
$$
  \rho(t,x) = 1 + \frac{1}{5} sin(2\pi (x - t)),
$$
$$
  q(t,x) = \rho(t,x)
$$
$$
  E(t,x) = \frac{1}{2} q(t,x).
$$

### Non smooth problems / Riemann problems
@guermond2008 gives a list of three test problems for the 1D case.
Because I had problems reproducing results for all these cases I also looked at
other test problems. The paper @liska2003 gives a set containing eight problems
(one of these uses a different gas constant, another one is specified on a
different domain). These test problems should serve as a check for my DG 
code to see if it works properly.
