---
title: Notes about literature
author: Florian Atteneder
bibliography: references.bib
...

# Notes about literature

---

## https://doi.org/10.1016/j.cma.2016.12.010
*Numerical investigation of a viscous regularization of the Euler equations
by entropy viscosity* - Nazarov, Larcher, 2017

They discuss that Navier-Stokes fluxes are not capable of stabilizing the Euler equation
with discontinuities, however, the Guermond-Popov flux can. They present and discuss both
fluxes. Because the Navier-Stokes flux does not respect a minimum entropy principle
in certain cases, the Guermond-Popov flux was constructed to account for this.

They also present the details of the computation of the entropy viscosity flux.
Their definition differs from the Zingan et al. 2013 paper in a way that they
use a nodal based viscosity, e.g. point-wise viscosity instead of cell-wise constant
viscosity.

They suggest two ways to compute the point-wise entropy residual
  1. via an integral over subcell elements (???)
  2. interpolation of the residual onto the reference basis element (I think
  this is what I do)

They use a SSPRK method and give an explicit formula for time stepping.

In section 3.6 a comparison between computations that use
the Navier-Stokes, Navier-Stokes + additional
viscosity for the mass equation and the Guermond-Popov flux is given.
In the presented 1D test case the Guermond-Popov flux performs best.

They state that implementing boundary conditions for the Euler equations is
not straightforward and they provide references to two books - look this up.
They also discuss so-called slip-boundary conditions (kind of reflective BCs?)
and how to impose them in the strong and the weak form. 

In section 5.1 they present numerical results for the smooth test problem for
the Euler equations in 2D and in 5.2 they present results for the non smooth
Sod shock tube test problem in 2D.


## https://www.math.purdue.edu/~zhan1966/research/paper/euler.pdf
On positivity preserving high order discontinuous Galerking schemes for
compressible Euler equations on rectangular meshes - Zhang, Shu, 2010

TODO Look up: 
- total variation diminishing (TVD) property,
- total variation bounded (TVB) limiter.
see [notes](notes.md)

The paper discusses how to enforce positivity of energy density and pressure
for the Euler equations in numerical simulations that use either finite volume
or DG methods. Positivity of these variables is needed, because otherwise
the system of Euler equations is not hyperbolic and, thus, not well defined 
anymore. In the introduction they mention that it is well known that when
solving hyperbolic conservation law system with high order numerical schemes,
the positivity of those quantities is generally not automatically guaranteed.

They give a simplified (compared to previous work) condition that has to be 
imposed onto the state vector during the numerical evolution. The proof
of this condition is based on concave and convex properties of functions and sets.
TODO Look up convexity and concavity of sets and functions.

The positivity is enforced by limiting the density first and the pressure 
afterwards. The limiting is done with a linear scaling factor. In Section 2
they give a recipe for their algorithm.

They also test their scheme numerical with different 1D and 2D smooth and
shock tube problems. To pass the shock tube test they use a TVB limiter
before they apply their positivity preserving limiter.
TODO Figure out if a TVB limiter is necessary or if the EV method serves as a
substitute for this.
The results look good and show that their method does the job, e.g.
conserves positivity. However, they do not provide results for calculations
where this is needed (maybe because in those cases the evolution is 
not possible like with my program and the blast wave tests?).

---

## https://www.math.tamu.edu/~bojan.popov/paper_CMAME_revised_2015_accepted.pdfp
Entropy viscosity method for the single material euler equations in Lagrangian
frame

The paper discusses the Euler equations expressed in the Lagrangian frame
(coordinates move with the fluid, e.g. time-dependent coordinate transformation
to reference element). They discuss this transformation explicitly.

They discuss entropy principles and they build their artificial viscosity
upon a generalized entropy density (which differs from the
physical one). They use the Guermond-Popov regularization to incorporate
artificial diffusion.

They discuss compatibility of the viscosity with general requirements
for artificial viscosity tensors (as discussed somewhere else). Those
requirements include 
  - invariance of the viscous terms wrt orthogonal transformations,
  - minimum principle of the specific entropy,
  - Galilean invariance of the regularized system,
  - preservation of radial symmetry,
  - no artificial dissipation in the momentum equation for linear velocities
  and no artificial viscosity diffusion in any equation for regions with
  expansion Those
  requirements include 
    - invariance of the viscous terms wrt orthogonal transformations,
    - minimum principle of the specific entropy,
    - Galilean invariance of the regularized system,
    - preservation of radial symmetry,
    - no artificial dissipation in the momentum equation for linear velocities
    and no artificial viscosity diffusion in any equation for regions with
    expansion.

They propose a time step control algorithm based on a heuristic technique,
but they do not mention why this algorithm is needed.

They solve the equations using a continuous FEM method with some
external FEM library. No details about the used grids are given, so I assume
they use equidistant ones. I have not studied all the results, I only looked
at the 1D shock tube test - the results look ok, but worse than
the ones presented in @zingan2012, @zingan2013.

In the conclusion they mention a follow up work in which they try to replace
the notion of artificial viscosity based on differential operators by 
a graph Laplacian approach.

### My thoughts
The discussion of compatibility properties may be useful for
extending the artificial viscosity method to relativistic problems
(Galilean -> Lorentz invariance). The time step control algorithm is worth
to implement and test to see whether it allows to over the problems of
blast wave tests. Also the follow up work may be of interest if it 
removes the necessity of computing second order derivatives.

---

## Entropy stable discontinuous Galerkin schemes for the Relativistic Euler equations
https://arxiv.org/abs/1911.07488

The work builds upon entropy conservative and entropy stable fluxes which are
defined in (23), (24). The names stem from the fact, that they guarantee
local conservation of entropy in single elements.
In (29) they give the entropy conservation flux (taken over from [36]).

Importantly: In Remark 1 they note that they use a bounds preserving limiter
to keep the solution in physical space!

They provide several tests for their 1D & 2D implementation. Perhaps I can
also use them to test my program.

### Thoughts
The results look good. The method is not yet clear to me, it looks like that
they just have used a suitable flux together with a limiter.
The presented results for the shock test problem 7 requires more than 2000 cells
(for k=1 and k=2 methods) to deliver acceptable results.


---

arXiv:1609.06792


---

doi:10.1016/j.jcp.2016.02.079

---

arxiv:2005.02317
