# Notes and thoughts about implementation

## Nonlinearities, aliasing, instabilities, etc.

In @hesthaven2007 (Chapter 5) they discuss a simple example that shows
that ordinary interpolation of the nonlinear flux of a conservation law
may lead to unstable schemes, because interpolation and differentiation do
not commute.

Q: Is this relevant for the problems we discuss?
Q: If not, how to deal with this?
  - @hesthaven2007 discuss solutions.

### Observation
Tests show that aliasing errors may potentially influence the appearance of
spurious oscillations. However, it seems like adjusting $c_e$ accordingly
allows to account for this, but only partially.

Further tests show that coefficients need to be tuned depending on the parity
of the polynomial order and number of sub cells.

TODO Investigate how viscosity behaves wrt those changes.

## Remaining oscillations

In @hesthaven2007 (p.144-145) they state that full spectral accuracy of
solutions containing discontinuities can be recovered by using so-called
Gibbs reconstruction methods. 
Q: Can this be applied to our problem as well where we see remaining 
oscillations? A: The answer can be found in the following section 'Limiting', 
which is no. This is, because the oscillations may introduce unphysical values
for temperature or pressure that prevent evolution. This is the case for the
Euler equations.


I think Bernd mentioned something that he would tune
the coefficients such that a bit of oscillations remain instead of introducing
too much dissipation.

## TVDM

In @hesthaven2007 (p.145f) the TVDM property is discussed.
TVDM stands for total variation diminishing in the mean, which means that the
mean value of a discretized solution over each cell is uniformly bounded
from above in order to avoid guarantee existence of the solution (e.g. the solution
remains finite over time). This property is not guaranteed automatically,
but must be enforced directly. This is the role of the (slope) limiter.
The limiter should be designed with three properties in mind:
- it does not violate conservation,
* it ensures that the TVDM constraints (5.21)-(5.23) are satisfied,
* it does not change the formal accuracy of the method.
The first tow are easy to satisfy, but the third property can cause problems.
That is, the limiter may flag smooth regions around extrema as oscillations
and, thus, introduce undesired artificial dissipation, e.g. it destroys
the high-order accuracy in smooth regions.

One way to overcome the issue of the loss of accuracy of accuracy around local extrema
is to relax the condition of the decay of the total variation of the mean and 
require that the total variation is just bounded (TVBM condition).

The minmod function allows to design limiters that carry the desired properties
mentioned above. See book for details.

