---
theme: mytheme
paginate: true
footer: "Florian Atteneder, 22.01.2021"
---

<!-- _class: title -->
# Conservation laws and the Discontinuous Galerkin method

---

<!-- _header: 
  "[Hesthaven, Warburton, 2007]
  <br/>
  [Kopriva, 2009]" -->
# Outline

- Conservation laws
- Discontinuous Galerkin Method

---

# Conservation laws

Conservation laws

$$
  \partial_t u + \partial_x f(u) = 0.
$$


Examples

- Advection eq.
  $$ 
    \partial_t u + \partial_x u = 0.
  $$
- (ideal) Burgers eq.
  $$ 
    \partial_t u + \partial_x u^2 = 0.
  $$

---

- (SR/GR) Euler eq. + EoS
  $$
    \partial_t \begin{bmatrix} \rho \\ v \rho \\ E \end{bmatrix}
    + \partial_x 
        \begin{bmatrix} 
          v \rho \\ v^2 \rho + p \\ v (E + p) 
        \end{bmatrix} = 0,
  $$


- Einstein field equations

  $$
    G^{\mu \nu} = \kappa T^{\mu\nu}
    \quad
    \Rightarrow
    \quad
    \partial_t u^{i}
    + A^{i}_{j} \partial_x u^{j} = s.
  $$


---

# Weak formulation

Conservation law
$$
  R = \partial_t u + \partial_x f(u) = 0,
$$

project onto $\psi$

$$
  \left( \partial_t u, \psi \right) 
  + \left( \partial_x f, \psi \right) = 0,
$$

perform integration by parts

$$
  \left( \partial_t u, \psi \right) 
    - \left( f, \partial_x \psi \right) 
    + [ f \psi ] 
    = 0.
$$


---

# Galerkin Method (I)

Local expansion
$$
  u_{\textcolor{blue}{k}}(t, x) =
  \sum_{\textcolor{red}{i}}
  \hat{u}_{\textcolor{blue}{k},\textcolor{red}{i}}(t)
  \phi_{\textcolor{blue}{k},\textcolor{red}{i}}(x)
  \in \mathbb{P}_{N},
$$

Global expansion
$$
  u(x,t) \approx \bigoplus_{\textcolor{blue}{k}\text{th cell in grid}} 
  u_{\textcolor{blue}{k}}(x, t).
$$

---

# Galerkin Method (II)

For each cell $\textcolor{blue}{k}$ determine $\{\hat{u}_{\textcolor{blue}{k},\textcolor{red}{i}}\}$ by

$$
  \left( \partial_t u_{\textcolor{blue}{k}}, \phi_{\textcolor{blue}{k},\textcolor{red}{j}} \right) 
    - \left( f_{\textcolor{blue}{k}}, \partial_x \phi_{\textcolor{blue}{k},\textcolor{red}{j}} \right) 
    + [ f_{\textcolor{blue}{k}} \phi_{\textcolor{blue}{k},\textcolor{red}{j}} ] 
    = 0,
    \qquad
    \forall \textcolor{red}{j}.
$$

<br/>

Your favourite quadrature rule yields
$$
  \textcolor{green}{\mathcal{M}}_{\textcolor{blue}{k}} \partial_{t} \hat{\textbf{u}}_{\textcolor{blue}{k}}
  = \textcolor{brown}{\mathcal{S}}_{\textcolor{blue}{k}}^{T} \textbf{f} 
  - [\textcolor{purple}{\boldsymbol{\phi}} f],
  \qquad
  \forall \textcolor{blue}{k},
$$

---

# Discontinuous Galerkin Method

Couple cells with numerical flux

$$
  f(u) \rightarrow f^{\ast}(u^{-}, u^{+}, n^-)
$$

Desired properties:
- Consistent
- Conservative

Example Lax-Friedrich Flux
$$
  n^- \cdot f^{\ast}(u^-, u^+, n^-) = \frac{1}{2}(f(u^-) + f(u^+)) 
                    - \frac{\alpha}{2} (u^- - u^+).
$$

---

# Galerkin Method (III)

#### Time stepping
$$
  \hat{\textbf{u}}_{\textcolor{blue}{k}}^{(n+1)}
  =
  \hat{\textbf{u}}^{(n)}_{\textcolor{blue}{k}}
  + \Delta t
  \textcolor{green}{\mathcal{M}}_{\textcolor{blue}{k}}^{-1} 
  (\textcolor{brown}{\mathcal{S}}_{\textcolor{blue}{k}}^{T} \textbf{f} 
  - [\textcolor{purple}{\boldsymbol{\phi}}_{\textcolor{blue}{k}} 
  f^{\textcolor{green}{\ast}}]),
  \qquad
  \forall \textcolor{blue}{k}.
$$

| Pros          | Cons                                                |
|---------------|-----------------------------------------------------|
| $hp$ adaptive | implicit scheme ($\mathcal{M}^{-1}$ block diagonal) |
|               | doubled DOF at boundaries                       |

---

<!-- _class: nobackground -->

![bg height:100%](advection_n1_k5.png) 

---

<!-- _class: nobackground -->

![bg height:100%](advection_n1_k10.png) 

---

<!-- _class: nobackground -->

![bg height:100%](advection_n1_k15.png) 

---

<!-- _class: nobackground -->

![bg height:100%](advection_n1_k55.png) 

---

<!-- _class: nobackground -->

![bg height:100%](advection_n1_k10.png) 

---

<!-- _class: nobackground -->

![bg height:100%](advection_n2_k10.png) 

---

<!-- _class: nobackground -->

![bg height:100%](advection_n5_k10.png) 

---

<!-- _class: nobackground -->

![bg height:100%](advection_n10_k1.png) 

---

<!-- _class: nobackground -->

![bg height:100%](advection_n15_k1.png) 

---

<!-- _class: nobackground -->

![bg height:100%](advection_n25_k1.png) 

---

<!-- _class: nobackground -->

![bg height:100%](advection_n55_k1.png) 

---

<!-- _header: "[Hesthaven, Warburton, 2007]" -->

# Convergence


$$
  "\text{Convergence = Stability + Consistency}"
$$

Linear problems

$$
  | u - u_{exact} |_{L^2} \leq C h^{N+1}, \qquad
  h = \frac{L}{K},
$$

nonlinear problems

$$
  | u - u_{exact} |_{L^2} \leq C h^{N+\nu}.
$$


---

# Summary

- Conservation laws describe important class of problems.

- DG __high order__ and __local__ but __implicit__ scheme.

<br/>

$$
  \text{Thank you}
$$

---

<!-- _class: chapter -->


---

# Reminder: Quadrature rules

$$
  \int_{a}^{b} f(x) w(x) dx = \sum_{i=0}^{N=N_{p}-1} f(x_{i}) w_{i} + R,
  \qquad
  f \in \mathbb{P}_{d}.
$$

| Rule          | $\textcolor{white}{R = 0}$ |
|---------------|------------|
| Gauss         | $d = 2N+1$ |
| Gauss-Radau   | $d = 2N$   |
| Gauss-Lobatto | $d = 2N-1$     |

---

<!-- _class: lineheight1 -->
# (Pseudo-)Spectral method

</br>

Hyperbolic PDE
$$
\partial_{\textcolor{blue}{t}} u 
  = L(u, \partial_{\textcolor{green}{x}} u),
  \qquad
  (t,x) \in [0,T] \times \Omega.
$$

Expansion
$$
  u(\textcolor{blue}{t},\textcolor{green}{x}) 
    \approx \sum_{i} 
      \hat{u}_i(\textcolor{blue}{t}) 
      \phi_i(\textcolor{green}{x}),
  \qquad
  \partial_{\textcolor{green}{x}} u(\textcolor{blue}{t},\textcolor{green}{x}) 
    \approx \sum_{i} 
      \hat{u}_i(\textcolor{blue}{t}) 
      \partial_{\textcolor{green}{x}} \phi_i(\textcolor{green}{x}).
$$

Explicit time integration, e.g. Euler method
$$
u^{(n+1)} = \delta t (u^{(n)} + L(u^{(n)}, \partial_x u^{(n)})).
$$

---

<!-- _class: lineheight1 -->
# Modal vs Nodal approximation

Modal expansion
$$
  u(x,t) \approx \sum_{i} \hat{u}_{i}(t) \phi(x)
$$

Nodal expansion
$$
  u(x,t) \approx \sum_{i} u(t, x_i) l_i(x).
$$

Quadrature rule establishes connection
$$
  \phi_i(x) = f(x, \{ l_j \}).
$$

---

# Weak and strong formulation

#### Nodal expansion + Quadrature rule

Weak form
$$
  \textcolor{green}{\mathcal{M}} \partial_{t} \textbf{u} 
  = \textcolor{blue}{\mathcal{S}^{T}} \textbf{f} 
  - [\textcolor{purple}{\mathbf{\ell}} f^{\ast}]
$$

Strong form
$$
  \textcolor{green}{\mathcal{M}} \partial_{t} \textbf{u} 
  = - \textcolor{blue}{\mathcal{S}} \textbf{f} 
  + [\textcolor{purple}{\mathbf{\ell}} (f - f^{\ast})]
$$

Mass matrix: $\textcolor{green}{M}_{ij} = \left( l_{i}, l_{j} \right)$,

Stiffness matrix: $\textcolor{blue}{S}_{ij} = \left( l_{i}, l'_{j} \right)$


---

# Numerical methods

Conservation law

$$
  R = \partial_t u + \partial_x f(u) = 0.
$$

Construction of scheme:

- How to approximation $u$?

- How to satisfy conservation law?

---

<!-- _header:
  "picture taken from [Hilditch, Weyhausen, Brügmann 2016]"
-->
# $\text{grid} = \cup_{i} \text{cell}_i$

![bg height:70%](bamps_grid_layout.png)

---

<!-- _class: title -->
# Shock Capturing techniques

Collaborators: Yorgos Doulis, 
Sebastiano Bernuzzi, Bernd Brügmann

---

# The problem

ideal Burgers equation

---

# Approaches

- High order methods
  - WENO, WENOZ, etc.

- Limiter
  - slope limiting
  - flux limiting

- Artificial viscosity

---

<!-- _header: "picture taken from [LeVeque, 1992]" -->

# Artifical Viscosity (I)

#### Example Burgers equation
<br/>

$$
  \partial_t u + \partial_x u^2 = \textcolor{green}{\epsilon} \partial_{xx} u,
  \qquad
  \textcolor{green}{\epsilon} \rightarrow 0
$$

![](leveque1992_viscosity_solution.png)


---

<!-- _header: "[Guermond et al. 2011, 2013]" -->
# Artifical Viscosity (II)

Regularize conservation law

$$
  \partial_t u + \partial_x f(u) = \textcolor{green}{\partial_x (\nu(u) \partial_x g(u))},
$$

<br/>

#### Challenges
- Hyperbolic Eq. $\rightarrow$ Parabolic Eq.
- How to chose $\nu(u), g(u)$?
- DG formulation of second order derivatives.
